@@ -1,6 +1,6 @@
 package Plack::Middleware::Precompressed;
 BEGIN {
-  $Plack::Middleware::Precompressed::VERSION = '1.003';
+  $Plack::Middleware::Precompressed::VERSION = '1.004';
 }
 use strict;
 use parent 'Plack::Middleware';
@@ -35,7 +35,7 @@ sub call {
 	return $res unless $have_match;
 
 	my $is_fail;
-	my $res = Plack::Util::response_cb( $res, sub {
+	my $final_res = Plack::Util::response_cb( $res, sub {
 		my $res = shift;
 		$is_fail = $res->[0] != 200;
 		return if $is_fail;
@@ -48,7 +48,7 @@ sub call {
 		return;
 	} );
 
-	return $is_fail ? $self->app->( $env ) : $res;
+	return $is_fail ? $self->app->( $env ) : $final_res;
 }
 
 1;
@@ -63,7 +63,7 @@ Plack::Middleware::Precompressed - serve pre-gzipped content to compression-enab
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
